@@ -44,8 +44,9 @@
 
 - (void) dealloc
 {
-  RELEASE(mpdController);
-  RELEASE(anTimer);
+  [mpdController release];
+  [anTimer release];
+  [randomPlaylistFeed release];
 
   [super dealloc];
 
@@ -67,11 +68,10 @@
   [window setFrameAutosaveName: @"PlayerWindow"];
 
   mpdController = [MPDController sharedMPDController];
+  randomPlaylistFeed = [[RandomPlaylistFeed alloc] init];
 
   prevState = state_NOCONN;
 
-
-
   [defCenter addObserver: self
 		selector: @selector(didDisconnect:)
 		    name: DidNotConnectNotification
@@ -110,7 +110,6 @@
     }
 
   [[LyricsInspector sharedLyricsInspector] showWindow: sender];
-
 }
 
 - (void) showSongInspector: (id)sender
@@ -121,7 +120,15 @@
     }
 
   [[SongInspector sharedSongInspector] showWindow: sender];
+}
 
+- (void) showPlaylistInspector: (id)sender
+{
+  if (! connected)
+    {
+      return;
+    }
+  [[PlaylistInspector sharedPlaylistInspector] showWindow: sender];
 }
 
 
@@ -133,7 +140,6 @@
     }
 
   [[PlaylistController sharedPlaylistController] showWindow: sender];
-
 }
 
 - (void) managePlaylists: (id)sender
@@ -574,7 +580,7 @@
       
       playlistLength = [mpdController getPlaylistLength];
       
-      currSong = RETAIN([mpdController getCurrentSong]);
+      currSong = [[mpdController getCurrentSong] retain];
       
       if (currentSongNr != playedSong) {
 	  playedSong = currentSongNr;
@@ -624,7 +630,7 @@
 	  [percentSlider setDoubleValue: (double)[currSong getElapsedTime]];
       }
       
-      RELEASE(currSong);
+      [currSong release];
   } else if (prevState != state_STOP) {
       NSImage *pImage;
 
