@@ -70,10 +70,10 @@ int _stringSort(id string1, id string2, void *context);
 {
   mpd_connection_free(mpdConnection);
 
-  RELEASE(host);
-  RELEASE(port);
-  RELEASE(password);
-  RELEASE(timeout);
+  [host release];
+  [port release];
+  [password release];
+  [timeout release];
 
   [super dealloc];
 }
@@ -91,16 +91,16 @@ int _stringSort(id string1, id string2, void *context);
       BOOL didConnect;
 
       if (host) {
-	  RELEASE(host);
+	  [host release];
       }
       if (port) {
-	  RELEASE(port);
+	  [port release];
       }
       if (password) {
-	  RELEASE(password);
+	  [password release];
       }
       if (port) {
-	  RELEASE(timeout);
+	  [timeout release];
       }
       host = [hostName copy];
       port = [portNr copy];
@@ -428,11 +428,10 @@ int _stringSort(id string1, id string2, void *context);
 
     mpd_stats_free(mpdStats);
     mpd_response_finish(mpdConnection);
-    return AUTORELEASE(statItem);
+    return [statItem autorelease];
   } else {
     return nil;
   }
-
 }
 
 /* ---------------------
@@ -470,7 +469,7 @@ int _stringSort(id string1, id string2, void *context);
 	  }
 	  mpdSong = mpd_recv_song(mpdConnection);
 	  
-	  currSong = RETAIN([self _getPlaylistItemForSong: mpdSong]);
+	  currSong = [[self _getPlaylistItemForSong: mpdSong] retain];
 	  
 	  [currSong setElapsedTime: mpd_status_get_elapsed_time(mpdStatus)];
 	  [currSong setTotalTime: mpd_status_get_total_time(mpdStatus)];
@@ -483,7 +482,7 @@ int _stringSort(id string1, id string2, void *context);
 
   if (currSong)
     {
-      return AUTORELEASE(currSong);
+      return [currSong autorelease];
     }
   else
     {
@@ -548,9 +547,9 @@ int _stringSort(id string1, id string2, void *context);
   while((mpdSong = mpd_recv_song(mpdConnection)) != NULL) {
 	  PlaylistItem *tmpSong;
 
-	  tmpSong = RETAIN([self _getPlaylistItemForSong: mpdSong]);
+	  tmpSong = [[self _getPlaylistItemForSong: mpdSong] retain];
 	  [playlist addObject: tmpSong];
-	  RELEASE(tmpSong);	
+	  [tmpSong release];
           mpd_song_free(mpdSong);
   }
   
@@ -563,7 +562,7 @@ int _stringSort(id string1, id string2, void *context);
   } else {
     currPlaylistVersion = 0;
   }
-  return AUTORELEASE(playlist);
+  return [playlist autorelease];
 }
 
 - (BOOL) collectionChanged
@@ -631,6 +630,18 @@ int _stringSort(id string1, id string2, void *context);
   mpd_run_delete(mpdConnection, song);
 }
 
+- (void) removeSongRange: (NSRange)songRange 
+{
+  if (! [self _checkConnection]) {
+      return;
+  }
+  if (songRange.location != NSNotFound)
+    {
+      mpd_run_delete_range(mpdConnection, songRange.location, songRange.length);
+    }
+}
+
+
 - (void) addTrack: (NSString *)file
 {
   if (! [self _checkConnection]) {
@@ -676,7 +687,7 @@ int _stringSort(id string1, id string2, void *context);
   }
   mpd_response_finish(mpdConnection);
   
-  return AUTORELEASE(tmpArray);
+  return [tmpArray autorelease];
   
 }
 
@@ -729,8 +740,8 @@ int _stringSort(id string1, id string2, void *context);
     }
 
   mpd_response_finish(mpdConnection);
-  return [AUTORELEASE(allArtists) sortedArrayUsingFunction: _stringSort 
-		                                   context: NULL];
+  return [[allArtists autorelease] sortedArrayUsingFunction: _stringSort 
+		                       context: NULL];
 }
 
 - (NSArray *) getAllAlbums
@@ -752,11 +763,11 @@ int _stringSort(id string1, id string2, void *context);
   }
 
   mpd_response_finish(mpdConnection);
-  return [AUTORELEASE(allAlbums) sortedArrayUsingFunction: _stringSort 
-		                                  context: NULL];
+  return [[allAlbums autorelease] sortedArrayUsingFunction: _stringSort 
+	                              context: NULL];
 }
 
-- (NSArray *) getAllTracks
+- (NSArray *) getAllTracksWithMetadata: (BOOL) withMetadata
 {
   NSMutableArray *allTracks;
   struct mpd_entity *mpdEntity;
@@ -766,24 +777,28 @@ int _stringSort(id string1, id string2, void *context);
   }
 
   allTracks = [[NSMutableArray alloc] init];
-  mpd_send_list_all_meta(mpdConnection, NULL);
-  while ((mpdEntity = mpd_recv_entity(mpdConnection)) != NULL) { 
-    if (mpd_entity_get_type(mpdEntity) == MPD_ENTITY_TYPE_SONG) {
-	  const struct mpd_song *mpdSong;
-	  PlaylistItem *tmpSong;
-
-	  mpdSong = mpd_entity_get_song(mpdEntity);
-
-	  tmpSong = RETAIN([self _getPlaylistItemForSong: mpdSong]);
-
-	  [allTracks addObject: tmpSong];
-	  
-	  RELEASE(tmpSong);
+  if (withMetadata)
+    {
+      mpd_send_list_all_meta(mpdConnection, NULL);
     }
+  else
+    {
+      mpd_send_list_all(mpdConnection, NULL);
+    }
+  while ((mpdEntity = mpd_recv_entity(mpdConnection)) != NULL) {
+    if (mpd_entity_get_type(mpdEntity) == MPD_ENTITY_TYPE_SONG) {
+          const struct mpd_song *mpdSong;
+          PlaylistItem *tmpSong;
+
+          mpdSong = mpd_entity_get_song(mpdEntity);
+          tmpSong = [[self _getPlaylistItemForSong: mpdSong] retain];
+          [allTracks addObject: tmpSong];
+	  [tmpSong release];
+    }
+    mpd_entity_free(mpdEntity);
   }
   mpd_response_finish(mpdConnection);
-  return AUTORELEASE(allTracks);
-
+  return [allTracks autorelease];
 }
 
 - (NSArray *) getAlbumsForArtist: (NSString *)artist
@@ -817,8 +832,8 @@ return nil;
   
   mpd_response_finish(mpdConnection);
 
-  return [AUTORELEASE(allAlbums) sortedArrayUsingFunction: _stringSort 
-		                                  context:NULL];
+  return [[allAlbums autorelease] sortedArrayUsingFunction: _stringSort 
+		                      context:NULL];
 */
 
 }
@@ -856,18 +871,18 @@ return nil;
 	  
 	  mpdSong = mpd_entity_get_song(mpdInfoEntity);
 
-	  tmpSong = RETAIN([self _getPlaylistItemForSong: mpdSong]);
+	  tmpSong = [[self _getPlaylistItemForSong: mpdSong] retain];
       
 	  [allTracks addObject: tmpSong];
 
-	  RELEASE(tmpSong);
+	  [tmpSong release];
 	}
       mpd_entity_free(mpdInfoEntity);
     }
   
   mpd_response_finish(mpdConnection);
   
-  return AUTORELEASE(allTracks);
+  return [allTracks autorelease];
 
 */
 }
@@ -879,7 +894,7 @@ return nil;
   NSMutableArray *allTracks;
   int i;
 
-  tmpArray = RETAIN([self getAllTracksForArtist: artist]);
+  tmpArray = [[self getAllTracksForArtist: artist] retain];
 
   if (! tmpArray) {
       return nil;
@@ -893,8 +908,8 @@ return nil;
       }
   }
   
-  RELEASE(tmpArray);
-  return AUTORELEASE(allTracks);
+  [tmpArray release];
+  return [allTracks autorelease];
 }
 
 - (NSArray *) getAllTracksForAlbum: (NSString *)album
@@ -930,18 +945,18 @@ return nil;
 	  
 	  mpdSong = mpd_entity_get_song(mpdInfoEntity);
 
-	  tmpSong = RETAIN([self _getPlaylistItemForSong: mpdSong]);
+	  tmpSong = [[self _getPlaylistItemForSong: mpdSong] retain];
 
 	  [allTracks addObject: tmpSong];
 	  
-	  RELEASE(tmpSong);
+	  [tmpSong release];
 	}
       mpd_entity_free(mpdInfoEntity);
     }
   
   mpd_response_finish(mpdConnection);
 
-  return AUTORELEASE(allTracks);;
+  return [allTracks autorelease];
 */
 }
 
@@ -1106,7 +1121,7 @@ return nil;
 
   [plItem setID: mpd_song_get_id(anSong)];
   [plItem setPos: mpd_song_get_pos(anSong)];
-  return AUTORELEASE(plItem);
+  return [plItem autorelease];
 }
 
 int _stringSort(id string1, id string2, void *context)
